@@ -43,7 +43,8 @@ class Git(object):
                 "--tags",
                 "--long",
                 "--abbrev=40",
-            ]).split("-")
+            ], stderr=subprocess.STDOUT
+            ).split("-")
         except subprocess.CalledProcessError:
             # logging.warn("Error when running git describe")
             return {}
@@ -145,7 +146,6 @@ def attempt_version_bump(args, context):
         elif bumped:
             parsed[label] = 0
 
-    assert bumped
     parsed.update(context)
 
     try:
@@ -250,13 +250,13 @@ def main(args=None):
     commitgroup = parser3.add_mutually_exclusive_group()
 
     commitgroup.add_argument('--commit', action='store_true', dest="commit",
-                         help='Commit to version control', default=False)
+                         help='Commit to version control', default=defaults.get("commit", False))
     commitgroup.add_argument('--no-commit', action='store_false', dest="commit",
                          help='Do not commit to version control', default=argparse.SUPPRESS)
 
     taggroup = parser3.add_mutually_exclusive_group()
 
-    taggroup.add_argument('--tag', action='store_true', dest="tag", default=False,
+    taggroup.add_argument('--tag', action='store_true', dest="tag",  default=defaults.get("commit", False),
                          help='Create a tag in version control')
     taggroup.add_argument('--no-tag', action='store_false', dest="tag",
                          help='Do not create a tag in version control', default=argparse.SUPPRESS)
@@ -286,6 +286,7 @@ def main(args=None):
             vcs.assert_nondirty()
             break
 
+    # make sure files exist and contain version string
     for path in args.files:
         with open(path, 'r') as f:
             before = f.read()
@@ -293,6 +294,11 @@ def main(args=None):
         assert args.current_version in before, 'Did not find string {} in file {}'.format(
             args.current_version, path)
 
+    # change version string in files
+    for path in args.files:
+        with open(path, 'r') as f:
+            before = f.read()
+
         after = before.replace(args.current_version, args.new_version)
 
         if not args.dry_run:
